/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbstractRulePackage.java 4490 2009-07-22 14:55:19Z nicoulaj $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.rules.manager.model;

/**
 * The base implementation of any kind of rule package
 *
 * @author Julien Nicoulaud
 */
public abstract class AbstractRulePackage implements IRulePackage {

	// =========================================================================
	// Properties
	// =========================================================================

    /**
     * The unique system name of the rule package. Identifies the object, must be
     * different for each rule package. Automatically generated from the rule
     * package "display" name.
     * @example "org.ow2.jasmine.monitoring.rules.example.ExamplePackage"
     */
    public String systemName;

    /**
     * The previous systemName of the package in the case where it
     * was modified. Used to identify the old rule package.
     */
    public String previousSystemName = null;

    /**
     * The displayed name of the rule package. This is the name that is choosed by
     * the user. Used to generate automatically the systemName property.
     * @example "Example Package"
     */
    public String displayName;
    
    /**
     * The name of the rule engine instance on which the rule is executed.
     */
    public String ruleEngineInstanceName;
    
	/**
	* Allowed states
	*/
	public static String DEACTIVATED = "deactivated";
	public static String ACTIVATED = "activated";
	public static String ACTIVATION_REQUESTED = "activationRequested";
	public static String DEACTIVATION_REQUESTED = "deactivationRequested";

    /**
     * The state of the rule package. Values can be:
     *   - Activated
     *   - Decativated
     *   - Activation requested
     *   - Deactivation requested
     */
    public String state = DEACTIVATED;

	/**
	* The description of the rule package
    */
	public String description;


    // =========================================================================
    // Getters and setters
    // =========================================================================

	/**
	 *
	 */
    public void setSystemName(final String value)
    {
    	systemName = value;
    }

    /**
     *
     */
    public String getSystemName()
    {
    	return systemName;
    }

    /**
     *
     */
    public void setPreviousSystemName(final String value)
    {
    	previousSystemName = value;
    }

    /**
     *
     */
    public String getPreviousSystemName()
    {
    	return previousSystemName;
    }

    /**
     *
     */
    public void setDisplayName(final String value)
    {
    	displayName = value;
    }

    /**
     *
     */
    public String getDisplayName()
    {
    	return displayName;
    }
    
    /**
     * Set the name of the rule engine instance on which the rule is executed.
     */
    public void setRuleEngineInstanceName(final String value) {
    	ruleEngineInstanceName = value;
    }
    
    /**
     * Set the name of the rule engine instance on which the rule is executed.
     */
    public String getRuleEngineInstanceName() {
    	return ruleEngineInstanceName;
    }
    
    /**
     *
     */
    public void setState(final String value)
    {
    	state = value;
    }

    /**
     *
     */
    public String getState()
    {
    	return state;
    }

    /**
     *
     */
    public void setDescription(final String value)
    {
    	description = value;
    }

    /**
     *
     */
    public String getDescription()
    {
    	return description;
    }


    // =========================================================================
    // Utils
    // =========================================================================

    /**
    * Returns a String preview of the object
    */
    @Override
	public String toString()
    {
    	return "{displayName:" + displayName +
    	       ",systemName:" + systemName +
               ",state:" + state + "}";

    }
}
