/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: VisualRulePackage.java 4626 2009-07-30 14:08:48Z nicoulaj $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.rules.manager.model.visual;

import java.util.ArrayList;
import java.util.List;

import org.ow2.jasmine.rules.manager.model.AbstractRulePackage;

/**
* A visual rule package
*
* @author Julien Nicoulaud
*
*/
public class VisualRulePackage extends AbstractRulePackage
                               implements IVisualRulePackage
{

	// =========================================================================
	// Variables
	// =========================================================================

    /**
	 * Serial version ID
	 */
	private static final long serialVersionUID = 1L;

	/**
    * The rules
    */
    public List<IRule> rules = new ArrayList<IRule>();

    /**
     * The imports
     */
    public List<String> imports = new ArrayList<String>();

    
    // =========================================================================
    // Getters and setters
    // =========================================================================

    /**
    * Set the rules collection
    */
    public void setRules(final List<IRule> value)
    {
        rules = value;
    }

    /**
    * Get the rules collection
    */
    public List<IRule> getRules()
    {
        return rules;
    }
    
	/**
	 * Set the imports
	 */
	public void setImports(List<String> value) {
		imports = value;
	}
	
	/**
	 * Get the imports
	 */
	public List<String> getImports() {
		return imports;
	}
	
	
    // =========================================================================
    // Utils
    // =========================================================================

    /**
    * Get the generated source in Drools syntax
    */
    public String getDrlSource()
    {
    	String source = "";

    	// Format the package statement
    	source += "package " + getSystemName();

    	// Format the imports section
    	for (String importStatement : imports) {
            source += "import " + importStatement + ";\n";
        }

    	// Format rules
        for (IRule rule : rules) {
    		source += "\n\n" + rule.getDrlSource();
    	}

        return source;
    }
}
